thelper.nn.sr package — thelper 0.3.8 documentation

### Navigation

- ☰
- thelper-0.3.8 »
- thelper package »
- thelper.nn package »

Fork me on GitHub

# thelper.nn.sr package

Neural network and model package for super resolution.

This package contains classes that define blocks and modules used in various neural network for super resolution architectures. Most of these classes have been adapted from external sources; see their individual headers for more information.

## Submodules

## thelper.nn.sr.srcnn module

class `thelper.nn.sr.srcnn.` `SRCNN`(task, num_channels=1, base_filter=64, groups=1)

  Bases: `thelper.nn.utils.Module`

  Implements the SRCNN architecture.

  See Dong et al., “Image Super-Resolution Using Deep Convolutional Networks” (2014) for more information (https://arxiv.org/abs/1501.00092).

  `__init__`(task, num_channels=1, base_filter=64, groups=1)

    Receives a task object to hold internally for model specialization.

  `forward`(x)

    Transforms an input tensor in order to generate a prediction.

  `set_task`(task)

    Adapts the model to support a new task, replacing layers if needed.

  `weight_init`()

## thelper.nn.sr.vdsr module

class `thelper.nn.sr.vdsr.` `VDSR`(task, num_channels=1, base_filter=64, kernel_size0=3, num_residuals=18, groups=1, activation='relu', norm='batch')

  Bases: `thelper.nn.utils.Module`

  Implements the VDSR architecture.

  See Kim et al., “Accurate Image Super-Resolution Using Very Deep Convolutional Networks” (2015) for more information (https://arxiv.org/abs/1511.04587).

  `__init__`(task, num_channels=1, base_filter=64, kernel_size0=3, num_residuals=18, groups=1, activation='relu', norm='batch')

    Receives a task object to hold internally for model specialization.

  `forward`(x)

    Transforms an input tensor in order to generate a prediction.

  `set_task`(task)

    Adapts the model to support a new task, replacing layers if needed.

  `weight_init`()

### Navigation

- index
- modules |
- next |
- previous |